MT19937

Struct MT19937 

pub struct MT19937 { /* private fields */ }
MT19937-64 Mersenne Twister BitGenerator.

Period 2^19937 - 1. The jump operation is not implemented for the 64-bit Mersenne Twister in this crate; the standard polynomial-jump table is large and not required for the typical use case.