Module generator

Module generator 

Structs

Generator
The main random number generator, wrapping a pluggable BitGenerator.

Functions

default_rng
Create a Generator with the default BitGenerator (Xoshiro256**) seeded from a non-deterministic source (using the system time as a simple entropy source).
default_rng_seeded
Create a Generator with the default BitGenerator (Xoshiro256**) from a specific seed, ensuring deterministic output.
spawn_generators
Spawn n independent child generators from this generator.